pub enum DecimalOperationError {
Overflow,
DivisionByZero,
}Expand description
Represents the possible errors that can occur during decimal operations.
Variants
Overflow
Indicates that an overflow occurred during the operation.
DivisionByZero
Indicates that a division by zero occurred during the operation.